Enum rustls::internal::msgs::enums::HashAlgorithm [−][src]
pub enum HashAlgorithm {
NONE,
MD5,
SHA1,
SHA224,
SHA256,
SHA384,
SHA512,
Unknown(u8),
}Variants
NONEMD5SHA1SHA224SHA256SHA384SHA512Unknown(u8)Methods
impl HashAlgorithm[src]
impl HashAlgorithmTrait Implementations
impl Debug for HashAlgorithm[src]
impl Debug for HashAlgorithmfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for HashAlgorithm[src]
impl PartialEq for HashAlgorithmfn eq(&self, other: &HashAlgorithm) -> bool[src]
fn eq(&self, other: &HashAlgorithm) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &HashAlgorithm) -> bool[src]
fn ne(&self, other: &HashAlgorithm) -> boolThis method tests for !=.
impl Eq for HashAlgorithm[src]
impl Eq for HashAlgorithmimpl Clone for HashAlgorithm[src]
impl Clone for HashAlgorithmfn clone(&self) -> HashAlgorithm[src]
fn clone(&self) -> HashAlgorithmReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Copy for HashAlgorithm[src]
impl Copy for HashAlgorithmimpl Codec for HashAlgorithm[src]
impl Codec for HashAlgorithmfn encode(&self, bytes: &mut Vec<u8>)[src]
fn encode(&self, bytes: &mut Vec<u8>)Encode yourself by appending onto bytes.
fn read(r: &mut Reader) -> Option<Self>[src]
fn read(r: &mut Reader) -> Option<Self>Decode yourself by fiddling with the Reader. Return Some if it worked, None if not. Read more
fn get_encoding(&self) -> Vec<u8>[src]
fn get_encoding(&self) -> Vec<u8>Convenience function to get the results of encode().
fn read_bytes(bytes: &[u8]) -> Option<Self>[src]
fn read_bytes(bytes: &[u8]) -> Option<Self>Read one of these from the front of bytes and return it. Read more