Enum rustls::internal::msgs::enums::SignatureAlgorithm [−][src]
pub enum SignatureAlgorithm {
Anonymous,
RSA,
DSA,
ECDSA,
Unknown(u8),
}Variants
AnonymousRSADSAECDSAUnknown(u8)Methods
impl SignatureAlgorithm[src]
impl SignatureAlgorithmTrait Implementations
impl Debug for SignatureAlgorithm[src]
impl Debug for SignatureAlgorithmfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for SignatureAlgorithm[src]
impl PartialEq for SignatureAlgorithmfn eq(&self, other: &SignatureAlgorithm) -> bool[src]
fn eq(&self, other: &SignatureAlgorithm) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &SignatureAlgorithm) -> bool[src]
fn ne(&self, other: &SignatureAlgorithm) -> boolThis method tests for !=.
impl Eq for SignatureAlgorithm[src]
impl Eq for SignatureAlgorithmimpl Clone for SignatureAlgorithm[src]
impl Clone for SignatureAlgorithmfn clone(&self) -> SignatureAlgorithm[src]
fn clone(&self) -> SignatureAlgorithmReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Copy for SignatureAlgorithm[src]
impl Copy for SignatureAlgorithmimpl Codec for SignatureAlgorithm[src]
impl Codec for SignatureAlgorithmfn encode(&self, bytes: &mut Vec<u8>)[src]
fn encode(&self, bytes: &mut Vec<u8>)Encode yourself by appending onto bytes.
fn read(r: &mut Reader) -> Option<Self>[src]
fn read(r: &mut Reader) -> Option<Self>Decode yourself by fiddling with the Reader. Return Some if it worked, None if not. Read more
fn get_encoding(&self) -> Vec<u8>[src]
fn get_encoding(&self) -> Vec<u8>Convenience function to get the results of encode().
fn read_bytes(bytes: &[u8]) -> Option<Self>[src]
fn read_bytes(bytes: &[u8]) -> Option<Self>Read one of these from the front of bytes and return it. Read more